@@ -1,14 +1,12 @@
-import requests
+import abc
 import json
 
+import requests
 
-json_headers = {
-    "accept": "application/json",
-    "Content-Type": "application/json"
-}
+json_headers = {"accept": "application/json", "Content-Type": "application/json"}
 
 
-class AuthHeader:
+class AuthHeader(abc.ABC):
     @property
     def headers(self):
         pass
@@ -38,11 +36,13 @@ class UserNameHeader(UserTokenHeader):
         self.password = password
         super().__init__(token=self.get_token())
 
-    def get_token(self):
+    def get_token(self) -> str:
         params = {
             "username": self.username,
             "password": self.password,
         }
         url = "http://localhost:8000/api/v1/auth/api-token/"
-        token = requests.post(url, data=json.dumps(params), headers=json_headers).json()['token']
-        return token
+        token = requests.post(url, data=json.dumps(params), headers=json_headers)
+        if token.status_code != 200:
+            raise Exception("Failed to get user token from server")
+        return token.json()["token"]
