@@ -1,30 +1,36 @@
 from typing import Dict, Literal, Optional, Union
 from uuid import UUID
 
-from grai_client.schemas.utilities import (BaseSpec, DispatchType,
-                                           PlaceHolderSchema)
+from grai_client.schemas.utilities import (BaseSpec,
+                                           PlaceHolderSchema, GraiBaseModel)
 from pydantic import BaseModel, Field
 from typing_extensions import Annotated
 
 
-class BaseNode(BaseModel):
-    type: Literal["Node"]
+class BaseNode(GraiBaseModel):
+    type: Literal["Node"] = "Node"
+
+    def __hash__(self):
+        return
 
 
-class V1(BaseSpec):
-    id: Optional[UUID]
+class NodeID(BaseModel):
     name: str
     namespace: str
-    data_source: str
-    display_name: Optional[str]
-    is_active: Optional[bool] = True
-    metadata: Optional[Dict] = {}
+    id: Optional[UUID]
 
     def __hash__(self):
         return hash(hash(self.name) + hash(self.namespace))
 
 
-class V2(PlaceHolderSchema, BaseSpec):
+class V1(NodeID, BaseSpec):
+    data_source: str
+    display_name: Optional[str]
+    is_active: Optional[bool] = True
+    metadata: Optional[Dict] = {}
+
+
+class V2(PlaceHolderSchema, V1):
     pass
 
 
@@ -32,13 +38,14 @@ class NodeV1(BaseNode):
     version: Literal["v1"]
     spec: V1
 
-    def from_spec(self, spec_dict: Dict) -> "NodeV1":
+    @classmethod
+    def from_spec(cls, spec_dict: Dict) -> "NodeV1":
         args = {
-            "version": self.version,
-            "type": self.type,
+            "version": "v1",
+            "type": "Node",
             "spec": spec_dict,
         }
-        return type(self)(**args)
+        return cls(**args)
 
 
 class NodeV2(BaseNode):
@@ -49,10 +56,6 @@ class NodeV2(BaseNode):
         raise NotImplementedError()
 
 
-class NodeType(DispatchType):
-    name: str = "nodes"
-    type: str = "Node"
-
-
+NodeLabels = Literal['nodes', 'node', 'Node', 'Nodes']
 NodeTypes = Union[NodeV1, NodeV2]
 Node = Annotated[NodeTypes, Field(discriminator="version")]
